@@ -1,5 +1,5 @@
 #define PCI_CONFIG_H
-#define PCI_ARCH_I386
+#define PCI_ARCH_POWERPC64
 #define PCI_OS_OPENBSD
 #define PCI_HAVE_PM_OBSD_DEVICE
 #define PCI_HAVE_PM_MMIO_CONF
@@ -14,4 +14,5 @@
 #define PCI_PATH_IDS_DIR "/usr/local/share"
 #define PCI_USE_DNS
 #define PCI_ID_DOMAIN "pci.id.ucw.cz"
-#define PCILIB_VERSION "3.10.0"
+#define PCILIB_VERSION "3.11.1"
+#define PCILIB_DATE_AMIGAOS "25.02.2024"
